@@ -1,3 +1,4 @@
+import logging
 from typing import List
 import grpc
 import time
@@ -19,30 +20,41 @@ class SnortIDSController:
     """
 
     @staticmethod
-    def start_snort_idses(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_snort_idses(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                          logger: logging.Logger) -> None:
         """
         Utility function for starting the Snort IDSes
 
         :param emulation_config: the emulation env configuration
-        :return:
+        :param physical_server_ip: the ip of the phsyical server
+        :param logger: the logger to use for logging
+        :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
-                    SnortIDSController.start_snort_ids(emulation_env_config=emulation_env_config, ip=c.get_ips()[0])
+                    logger.info(f"Starting the Snort IDS on IP: {c.docker_gw_bridge_ip}")
+                    SnortIDSController.start_snort_ids(emulation_env_config=emulation_env_config,
+                                                       ip=c.docker_gw_bridge_ip)
 
     @staticmethod
-    def stop_snort_idses(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_snort_idses(emulation_env_config: EmulationEnvConfig, physical_server_ip: str) -> None:
         """
         Utility function for stopping the Snort IDSes
 
         :param emulation_config: the emulation env configuration
-        :return:
+        :param physical_server_ip: the ip of the physical server
+        :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
-                    SnortIDSController.stop_snort_ids(emulation_env_config=emulation_env_config, ip=c.get_ips()[0])
+                    SnortIDSController.stop_snort_ids(emulation_env_config=emulation_env_config,
+                                                      ip=c.docker_gw_bridge_ip)
 
     @staticmethod
     def start_snort_ids(emulation_env_config: EmulationEnvConfig, ip: str) -> None:
@@ -89,17 +101,21 @@ class SnortIDSController:
                 csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids(stub=stub)
 
     @staticmethod
-    def start_snort_managers(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_snort_managers(emulation_env_config: EmulationEnvConfig, physical_server_ip: str) -> None:
         """
-        Utility funciton for starting snort IDS managers
+        Utility function for starting snort IDS managers
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the physical server ip
         :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
-                    SnortIDSController.start_snort_manager(emulation_env_config=emulation_env_config, ip=c.get_ips()[0])
+                    SnortIDSController.start_snort_manager(emulation_env_config=emulation_env_config,
+                                                           ip=c.docker_gw_bridge_ip)
 
     @staticmethod
     def start_snort_manager(emulation_env_config: EmulationEnvConfig, ip: str) -> None:
@@ -138,17 +154,21 @@ class SnortIDSController:
             time.sleep(2)
 
     @staticmethod
-    def stop_snort_managers(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_snort_managers(emulation_env_config: EmulationEnvConfig, physical_server_ip: str) -> None:
         """
         Utility function for stopping snort IDS managers
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the physical server ip
         :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
-                    SnortIDSController.stop_snort_manager(emulation_env_config=emulation_env_config, ip=c.get_ips()[0])
+                    SnortIDSController.stop_snort_manager(emulation_env_config=emulation_env_config,
+                                                          ip=c.docker_gw_bridge_ip)
 
     @staticmethod
     def stop_snort_manager(emulation_env_config: EmulationEnvConfig, ip: str) -> None:
@@ -170,19 +190,25 @@ class SnortIDSController:
         time.sleep(2)
 
     @staticmethod
-    def start_snort_idses_monitor_threads(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_snort_idses_monitor_threads(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                                          logger: logging.Logger) -> None:
         """
         A method that sends a request to the SnortIDSManager on every container that runs
         an IDS to start the IDS manager and the monitor thread
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
+                    logger.info(f"Starting Snort IDS monitor thread on IP: {c.docker_gw_bridge_ip}")
                     SnortIDSController.start_snort_idses_monitor_thread(emulation_env_config=emulation_env_config,
-                                                                        ip=c.get_ips()[0])
+                                                                        ip=c.docker_gw_bridge_ip)
 
     @staticmethod
     def start_snort_idses_monitor_thread(emulation_env_config: EmulationEnvConfig, ip: str) -> None:
@@ -213,19 +239,22 @@ class SnortIDSController:
                     time_step_len_seconds=emulation_env_config.snort_ids_manager_config.time_step_len_seconds)
 
     @staticmethod
-    def stop_snort_idses_monitor_threads(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_snort_idses_monitor_threads(emulation_env_config: EmulationEnvConfig, physical_server_ip: str) -> None:
         """
         A method that sends a request to the SnortIDSManager on every container that runs
         an IDS to stop the monitor threads
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the physical server ip
         :return: None
         """
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
                     SnortIDSController.stop_snort_idses_monitor_thread(emulation_env_config=emulation_env_config,
-                                                                       ip=c.get_ips()[0])
+                                                                       ip=c.docker_gw_bridge_ip)
 
     @staticmethod
     def stop_snort_idses_monitor_thread(emulation_env_config: EmulationEnvConfig, ip: str) -> None:
@@ -248,7 +277,7 @@ class SnortIDSController:
             csle_collector.snort_ids_manager.query_snort_ids_manager.stop_snort_ids_monitor(stub=stub)
 
     @staticmethod
-    def get_snort_idses_monitor_threads_statuses(emulation_env_config: EmulationEnvConfig,
+    def get_snort_idses_monitor_threads_statuses(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
                                                  start_if_stopped: bool = True) -> \
             List[csle_collector.snort_ids_manager.snort_ids_manager_pb2.SnortIdsMonitorDTO]:
         """
@@ -257,17 +286,22 @@ class SnortIDSController:
 
         :param emulation_env_config: the emulation config
         :param start_if_stopped: whether to start the IDS monitor if it is stopped
+        :param physical_server_ip: the physical server IP
         :return: List of monitor thread statuses
         """
         statuses = []
         if start_if_stopped:
-            SnortIDSController.start_snort_managers(emulation_env_config=emulation_env_config)
+            SnortIDSController.start_snort_managers(emulation_env_config=emulation_env_config,
+                                                    physical_server_ip=physical_server_ip)
 
         for c in emulation_env_config.containers_config.containers:
+            if c.physical_host_ip != physical_server_ip:
+                continue
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
                     status = SnortIDSController.get_snort_idses_monitor_threads_statuses_by_ip_and_port(
-                        port=emulation_env_config.snort_ids_manager_config.snort_ids_manager_port, ip=c.get_ips()[0])
+                        port=emulation_env_config.snort_ids_manager_config.snort_ids_manager_port,
+                        ip=c.docker_gw_bridge_ip)
                     statuses.append(status)
         return statuses
 
@@ -289,34 +323,6 @@ class SnortIDSController:
                     stub=stub)
             return status
 
-    @staticmethod
-    def get_snort_idses_log_data(emulation_env_config: EmulationEnvConfig, timestamp: float) \
-            -> List[csle_collector.snort_ids_manager.snort_ids_manager_pb2.SnortIdsLogDTO]:
-        """
-        A method that sends a request to the Snort IDSManager on every container to get contents of the IDS log from
-        a given timestamp
-
-        :param emulation_env_config: the emulation env config
-        :param timestamp: the timestamp to read the IDS log from
-        :return: List of monitor thread statuses
-        """
-        ids_log_data_list = []
-        SnortIDSController.start_snort_managers(emulation_env_config=emulation_env_config)
-
-        for c in emulation_env_config.containers_config.containers:
-            for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
-                if ids_image in c.name:
-                    # Open a gRPC session
-                    with grpc.insecure_channel(
-                            f'{c.get_ips()[0]}:'
-                            f'{emulation_env_config.snort_ids_manager_config.snort_ids_manager_port}') as channel:
-                        stub = csle_collector.snort_ids_manager.snort_ids_manager_pb2_grpc.SnortIdsManagerStub(channel)
-                        ids_log_data = csle_collector.snort_ids_manager.query_snort_ids_manager.get_snort_ids_alerts(
-                            stub=stub, timestamp=timestamp,
-                            log_file_path=csle_collector_constants.SNORT_IDS_ROUTER.SNORT_FAST_LOG_FILE)
-                        ids_log_data_list.append(ids_log_data)
-        return ids_log_data_list
-
     @staticmethod
     def get_snort_ids_managers_ips(emulation_env_config: EmulationEnvConfig) -> List[str]:
         """
@@ -329,7 +335,7 @@ class SnortIDSController:
         for c in emulation_env_config.containers_config.containers:
             for ids_image in constants.CONTAINER_IMAGES.SNORT_IDS_IMAGES:
                 if ids_image in c.name:
-                    ips.append(c.get_ips()[0])
+                    ips.append(c.docker_gw_bridge_ip)
         return ips
 
     @staticmethod
@@ -348,13 +354,15 @@ class SnortIDSController:
         return ports
 
     @staticmethod
-    def get_snort_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str]) \
-            -> SnortIdsManagersInfo:
+    def get_snort_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str],
+                                logger: logging.Logger, physical_server_ip: str) -> SnortIdsManagersInfo:
         """
         Extracts the information of the Snort managers for a given emulation
 
         :param emulation_env_config: the configuration of the emulation
         :param active_ips: list of active IPs
+        :param physical_server_ip: the IP of the physical server
+        :param logger: the logger to use for logging
         :return: a DTO with the status of the Snort managers
         """
         snort_ids_managers_ips = SnortIDSController.get_snort_ids_managers_ips(
@@ -364,7 +372,8 @@ class SnortIDSController:
         snort_managers_statuses = []
         snort_managers_running = []
         for ip in snort_ids_managers_ips:
-            if ip not in active_ips:
+            if ip not in active_ips or not EmulationUtil.physical_ip_match(
+                    emulation_env_config=emulation_env_config, ip=ip, physical_host_ip=physical_server_ip):
                 continue
             running = False
             status = None
@@ -373,7 +382,7 @@ class SnortIDSController:
                     port=emulation_env_config.snort_ids_manager_config.snort_ids_manager_port, ip=ip)
                 running = True
             except Exception as e:
-                Logger.__call__().get_logger().debug(
+                logger.debug(
                     f"Could not fetch Snort IDS manager status on IP:{ip}, error: {str(e)}, {repr(e)}")
             if status is not None:
                 snort_managers_statuses.append(status)
