@@ -1,3 +1,4 @@
+import logging
 from typing import List
 import time
 import grpc
@@ -17,7 +18,6 @@ from csle_common.dao.emulation_config.traffic_managers_info import TrafficManage
 from csle_common.dao.emulation_config.node_container_config import NodeContainerConfig
 from csle_common.util.emulation_util import EmulationUtil
 from csle_common.dao.emulation_config.client_population_process_type import ClientPopulationProcessType
-from csle_common.logging.log import Logger
 
 
 class TrafficController:
@@ -26,100 +26,118 @@ class TrafficController:
     """
 
     @staticmethod
-    def start_traffic_managers(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_traffic_managers(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                               logger: logging.Logger) -> None:
         """
         Utility method for checking if the traffic manager is running and starting it if it is not running
         on every node
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
-
+            if node_traffic_config.physical_host_ip != physical_server_ip:
+                continue
             # Connect
             TrafficController.start_traffic_manager(emulation_env_config=emulation_env_config,
-                                                    node_traffic_config=node_traffic_config)
+                                                    node_traffic_config=node_traffic_config,
+                                                    logger=logger)
 
     @staticmethod
     def start_traffic_manager(emulation_env_config: EmulationEnvConfig,
-                              node_traffic_config: NodeTrafficConfig) -> None:
+                              node_traffic_config: NodeTrafficConfig,
+                              logger: logging.Logger) -> None:
         """
         Utility method for starting traffic manager on a specific container
 
         :param emulation_env_config: the emulation env config
         :param node_traffic_config: traffic config of the container
+        :param logger: the logger to use for logging
         :return: None
         """
         # Connect
-        EmulationUtil.connect_admin(emulation_env_config=emulation_env_config, ip=node_traffic_config.ip)
+        EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
+                                    ip=node_traffic_config.docker_gw_bridge_ip)
 
         # Check if traffic_manager is already running
         cmd = (constants.COMMANDS.PS_AUX + " | " + constants.COMMANDS.GREP + constants.COMMANDS.SPACE_DELIM
                + constants.TRAFFIC_COMMANDS.TRAFFIC_MANAGER_FILE_NAME)
         o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd,
-                                                conn=emulation_env_config.get_connection(ip=node_traffic_config.ip))
+                                                conn=emulation_env_config.get_connection(
+                                                    ip=node_traffic_config.docker_gw_bridge_ip))
 
         if constants.COMMANDS.SEARCH_TRAFFIC_MANAGER not in str(o):
-
-            Logger.__call__().get_logger().info(f"Starting traffic manager on node {node_traffic_config.ip}")
-
             # Stop old background job if running
             cmd = (constants.COMMANDS.SUDO + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PKILL +
                    constants.COMMANDS.SPACE_DELIM + constants.TRAFFIC_COMMANDS.TRAFFIC_MANAGER_FILE_NAME)
             o, e, _ = EmulationUtil.execute_ssh_cmd(
-                cmd=cmd, conn=emulation_env_config.get_connection(ip=node_traffic_config.ip))
+                cmd=cmd, conn=emulation_env_config.get_connection(ip=node_traffic_config.docker_gw_bridge_ip))
 
             # Start the _manager
             cmd = constants.COMMANDS.START_TRAFFIC_MANAGER.format(node_traffic_config.traffic_manager_port,
                                                                   node_traffic_config.traffic_manager_log_dir,
                                                                   node_traffic_config.traffic_manager_log_file,
                                                                   node_traffic_config.traffic_manager_max_workers)
+            logger.info(f"Starting traffic manager on node "
+                        f"{node_traffic_config.docker_gw_bridge_ip}, with cmd:{cmd}")
             o, e, _ = EmulationUtil.execute_ssh_cmd(
-                cmd=cmd, conn=emulation_env_config.get_connection(ip=node_traffic_config.ip))
+                cmd=cmd, conn=emulation_env_config.get_connection(ip=node_traffic_config.docker_gw_bridge_ip))
             time.sleep(2)
 
     @staticmethod
-    def stop_traffic_managers(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_traffic_managers(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                              logger: logging.Logger) -> None:
         """
-        Utility method for stopping traffic managers
+        Utility method for stopping traffic managers on a given server
 
         :param emulation_env_config: the emulation env config
+        :param physical_server_ip: the ip of the physical server to stop the traffic managers
+        :param logger: the logger to use for logging
         :return: None
         """
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
-            TrafficController.stop_traffic_manager(emulation_env_config=emulation_env_config,
-                                                   node_traffic_config=node_traffic_config)
+            if node_traffic_config.physical_host_ip == physical_server_ip:
+                TrafficController.stop_traffic_manager(emulation_env_config=emulation_env_config,
+                                                       node_traffic_config=node_traffic_config, logger=logger)
 
     @staticmethod
-    def stop_traffic_manager(emulation_env_config: EmulationEnvConfig, node_traffic_config: NodeTrafficConfig) -> None:
+    def stop_traffic_manager(emulation_env_config: EmulationEnvConfig, node_traffic_config: NodeTrafficConfig,
+                             logger: logging.Logger) -> None:
         """
         Utility method for stopping a specific traffic manager
 
         :param emulation_env_config: the emulation env config
         :param node_traffic_config: the node traffic configuration
+        :param logger: the logger to use for logging
         :return: None
         """
         # Connect
-        EmulationUtil.connect_admin(emulation_env_config=emulation_env_config, ip=node_traffic_config.ip)
-        Logger.__call__().get_logger().info(f"Stopping traffic manager on node {node_traffic_config.ip}")
+        EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
+                                    ip=node_traffic_config.docker_gw_bridge_ip)
+        logger.info(f"Stopping traffic manager on node {node_traffic_config.docker_gw_bridge_ip}")
 
         # Stop old background job if running
         cmd = (constants.COMMANDS.SUDO + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PKILL +
                constants.COMMANDS.SPACE_DELIM + constants.TRAFFIC_COMMANDS.TRAFFIC_MANAGER_FILE_NAME)
         o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd,
-                                                conn=emulation_env_config.get_connection(ip=node_traffic_config.ip))
+                                                conn=emulation_env_config.get_connection(
+                                                    ip=node_traffic_config.docker_gw_bridge_ip))
 
     @staticmethod
-    def start_client_manager(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_client_manager(emulation_env_config: EmulationEnvConfig, logger: logging.Logger) -> None:
         """
         Utility method starting the client manager
 
         :param emulation_env_config: the emulation env config
+        :param logger: the logger to use for logging
         :return: None
         """
         # Connect
-        EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
-                                    ip=emulation_env_config.traffic_config.client_population_config.ip)
+        EmulationUtil.connect_admin(
+            emulation_env_config=emulation_env_config,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip)
 
         # Check if client_manager is already running
         cmd = (constants.COMMANDS.PS_AUX + " | " + constants.COMMANDS.GREP + constants.COMMANDS.SPACE_DELIM +
@@ -127,17 +145,18 @@ class TrafficController:
         o, e, _ = EmulationUtil.execute_ssh_cmd(
             cmd=cmd,
             conn=emulation_env_config.get_connection(
-                ip=emulation_env_config.traffic_config.client_population_config.ip))
+                ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip))
 
         if constants.COMMANDS.SEARCH_CLIENT_MANAGER not in str(o):
-            Logger.__call__().get_logger().info(f"Starting client manager on node "
-                                                f"{emulation_env_config.traffic_config.client_population_config.ip}")
+            logger.info(
+                f"Starting client manager on node "
+                f"{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
 
             # Stop old background job if running
             cmd = (constants.COMMANDS.SUDO + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PKILL +
                    constants.COMMANDS.SPACE_DELIM + constants.TRAFFIC_COMMANDS.CLIENT_MANAGER_FILE_NAME)
             o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=emulation_env_config.get_connection(
-                ip=emulation_env_config.traffic_config.client_population_config.ip))
+                ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip))
 
             # Start the client_manager
             cmd = constants.COMMANDS.START_CLIENT_MANAGER.format(
@@ -147,11 +166,11 @@ class TrafficController:
                 emulation_env_config.traffic_config.client_population_config.client_manager_max_workers
             )
             o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=emulation_env_config.get_connection(
-                ip=emulation_env_config.traffic_config.client_population_config.ip))
+                ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip))
             time.sleep(2)
 
     @staticmethod
-    def stop_client_manager(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_client_manager(emulation_env_config: EmulationEnvConfig, logger: logging.Logger) -> None:
         """
         Utility method starting the client manager
 
@@ -160,64 +179,71 @@ class TrafficController:
         """
         # Connect
         EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
-                                    ip=emulation_env_config.traffic_config.client_population_config.ip)
+                                    ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip)
 
-        Logger.__call__().get_logger().info(f"Stopping client manager on node "
-                                            f"{emulation_env_config.traffic_config.client_population_config.ip}")
+        logger.info(f"Stopping client manager on node "
+                    f"{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
 
         # Stop old background job if running
         cmd = (constants.COMMANDS.SUDO + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PKILL +
                constants.COMMANDS.SPACE_DELIM + constants.TRAFFIC_COMMANDS.CLIENT_MANAGER_FILE_NAME)
         o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=emulation_env_config.get_connection(
-            ip=emulation_env_config.traffic_config.client_population_config.ip))
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip))
 
     @staticmethod
-    def stop_client_population(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_client_population(emulation_env_config: EmulationEnvConfig, logger: logging.Logger) -> None:
         """
         Function for stopping the client arrival process of an emulation
 
         :param emulation_env_config: the emulation env config
+        :param logger: the logger to use for logging
         :return: None
         """
-        Logger.__call__().get_logger().info(f"Stopping client population on container: "
-                                            f"{emulation_env_config.traffic_config.client_population_config.ip}")
+        logger.info(
+            f"Stopping client population on container: "
+            f"{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
 
-        TrafficController.start_client_manager(emulation_env_config=emulation_env_config)
+        TrafficController.start_client_manager(emulation_env_config=emulation_env_config, logger=logger)
 
         client_dto = TrafficController.get_clients_dto_by_ip_and_port(
-            ip=emulation_env_config.traffic_config.client_population_config.ip,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip,
             port=emulation_env_config.traffic_config.client_population_config.client_manager_port)
 
         if client_dto.client_process_active:
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{emulation_env_config.traffic_config.client_population_config.ip}:'
+                    f'{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}:'
                     f'{emulation_env_config.traffic_config.client_population_config.client_manager_port}') as channel:
                 stub = csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub(channel)
                 csle_collector.client_manager.query_clients.stop_clients(stub)
 
     @staticmethod
-    def start_client_producer(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_client_producer(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                              logger: logging.Logger) -> None:
         """
         Starts the Kafka producer for client metrics
 
         :param emulation_env_config: the emulation environment configuration
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
-        Logger.__call__().get_logger().info(f"Starting client producer on container:"
-                                            f" {emulation_env_config.traffic_config.client_population_config.ip}")
+        if emulation_env_config.traffic_config.client_population_config.physical_host_ip != physical_server_ip:
+            return
+        logger.info(
+            f"Starting client producer on container:"
+            f" {emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
 
-        TrafficController.start_client_manager(emulation_env_config=emulation_env_config)
+        TrafficController.start_client_manager(emulation_env_config=emulation_env_config, logger=logger)
 
         client_dto = TrafficController.get_clients_dto_by_ip_and_port(
-            ip=emulation_env_config.traffic_config.client_population_config.ip,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip,
             port=emulation_env_config.traffic_config.client_population_config.client_manager_port
         )
         if not client_dto.producer_active:
-
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{emulation_env_config.traffic_config.client_population_config.ip}:'
+                    f'{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}:'
                     f'{emulation_env_config.traffic_config.client_population_config.client_manager_port}') as channel:
                 stub = csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub(channel)
 
@@ -228,27 +254,34 @@ class TrafficController:
                     time_step_len_seconds=emulation_env_config.kafka_config.time_step_len_seconds)
 
     @staticmethod
-    def stop_client_producer(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_client_producer(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                             logger: logging.Logger) -> None:
         """
         Stops the Kafka producer for client metrics
 
         :param emulation_env_config: the emulation environment configuration
+        :param physical_server_ip: ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
-        Logger.__call__().get_logger().info(f"Stopping client producer on container:"
-                                            f" {emulation_env_config.traffic_config.client_population_config.ip}")
+        if emulation_env_config.traffic_config.client_population_config.physical_host_ip != physical_server_ip:
+            return
 
-        TrafficController.start_client_manager(emulation_env_config=emulation_env_config)
+        logger.info(
+            f"Stopping client producer on container:"
+            f" {emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
+
+        TrafficController.start_client_manager(emulation_env_config=emulation_env_config, logger=logger)
 
         client_dto = TrafficController.get_clients_dto_by_ip_and_port(
-            ip=emulation_env_config.traffic_config.client_population_config.ip,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip,
             port=emulation_env_config.traffic_config.client_population_config.client_manager_port
         )
 
         if client_dto.producer_active:
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{emulation_env_config.traffic_config.client_population_config.ip}:'
+                    f'{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}:'
                     f'{emulation_env_config.traffic_config.client_population_config.client_manager_port}') as channel:
                 stub = csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub(channel)
 
@@ -256,15 +289,21 @@ class TrafficController:
                 csle_collector.client_manager.query_clients.stop_producer(stub=stub)
 
     @staticmethod
-    def start_client_population(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_client_population(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                                logger: logging.Logger) -> None:
         """
         Starts the arrival process of clients
 
         :param emulation_env_config: the emulation environment configuration
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
-        Logger.__call__().get_logger().info(f"Starting client population on container: "
-                                            f"{emulation_env_config.traffic_config.client_population_config.ip}")
+        if emulation_env_config.traffic_config.client_population_config.physical_host_ip != physical_server_ip:
+            return
+        logger.info(
+            f"Starting client population on container: "
+            f"{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}")
         commands = []
         reachable_containers = []
 
@@ -289,16 +328,16 @@ class TrafficController:
             for cmd in constants.TRAFFIC_COMMANDS.DEFAULT_COMMANDS[constants.TRAFFIC_COMMANDS.CLIENT_1_SUBNET]:
                 commands.append(cmd.format(net.subnet_mask))
 
-        TrafficController.start_client_manager(emulation_env_config=emulation_env_config)
+        TrafficController.start_client_manager(emulation_env_config=emulation_env_config, logger=logger)
 
         client_dto = TrafficController.get_clients_dto_by_ip_and_port(
-            ip=emulation_env_config.traffic_config.client_population_config.ip,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip,
             port=emulation_env_config.traffic_config.client_population_config.client_manager_port
         )
 
         # Open a gRPC session
         with grpc.insecure_channel(
-                f'{emulation_env_config.traffic_config.client_population_config.ip}:'
+                f'{emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip}:'
                 f'{emulation_env_config.traffic_config.client_population_config.client_manager_port}') as channel:
             stub = csle_collector.client_manager.client_manager_pb2_grpc.ClientManagerStub(channel)
 
@@ -325,19 +364,20 @@ class TrafficController:
             )
 
     @staticmethod
-    def get_num_active_clients(emulation_env_config: EmulationEnvConfig) \
+    def get_num_active_clients(emulation_env_config: EmulationEnvConfig, logger: logging.Logger) \
             -> csle_collector.client_manager.client_manager_pb2.ClientsDTO:
         """
         Gets the number of active clients
 
         :param emulation_env_config: the emulation configuration
+        :param logger: the logger to use for logging
         :return: A ClientDTO which contains the number of active clients
         """
 
-        TrafficController.start_client_manager(emulation_env_config=emulation_env_config)
+        TrafficController.start_client_manager(emulation_env_config=emulation_env_config, logger=logger)
 
         client_dto = TrafficController.get_clients_dto_by_ip_and_port(
-            ip=emulation_env_config.traffic_config.client_population_config.ip,
+            ip=emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip,
             port=emulation_env_config.traffic_config.client_population_config.client_manager_port)
         return client_dto
 
@@ -359,47 +399,58 @@ class TrafficController:
             return status
 
     @staticmethod
-    def stop_internal_traffic_generators(emulation_env_config: EmulationEnvConfig) -> None:
+    def stop_internal_traffic_generators(emulation_env_config: EmulationEnvConfig, logger: logging.Logger,
+                                         physical_server_ip: str) -> None:
         """
         Utility function for stopping internal traffic generators
 
         :param emulation_env_config: the configuration of the emulation env
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
-            TrafficController.stop_internal_traffic_generator(emulation_env_config=emulation_env_config,
-                                                              node_traffic_config=node_traffic_config)
+            if node_traffic_config.physical_host_ip == physical_server_ip:
+                TrafficController.stop_internal_traffic_generator(emulation_env_config=emulation_env_config,
+                                                                  node_traffic_config=node_traffic_config,
+                                                                  logger=logger)
 
     @staticmethod
     def stop_internal_traffic_generator(emulation_env_config: EmulationEnvConfig,
-                                        node_traffic_config: NodeTrafficConfig) -> None:
+                                        node_traffic_config: NodeTrafficConfig, logger: logging.Logger) -> None:
         """
         Utility function for stopping a specific internal traffic generator
 
         :param emulation_env_config: the configuration of the emulation env
+        :param logger: the logger to use for logging
         :param node_traffic_config: the node traffic config
         :return: None
         """
         TrafficController.start_traffic_manager(emulation_env_config=emulation_env_config,
-                                                node_traffic_config=node_traffic_config)
-        Logger.__call__().get_logger().info(f"Stopping traffic generator script, "
-                                            f"node ip:{node_traffic_config.ip}")
+                                                node_traffic_config=node_traffic_config, logger=logger)
+        logger.info(f"Stopping traffic generator script, "
+                    f"node ip:{node_traffic_config.docker_gw_bridge_ip}")
 
         # Open a gRPC session
         with grpc.insecure_channel(
-                f'{node_traffic_config.ip}:{node_traffic_config.traffic_manager_port}') as channel:
+                f'{node_traffic_config.docker_gw_bridge_ip}:{node_traffic_config.traffic_manager_port}') as channel:
             stub = csle_collector.traffic_manager.traffic_manager_pb2_grpc.TrafficManagerStub(channel)
             csle_collector.traffic_manager.query_traffic_manager.stop_traffic(stub)
 
     @staticmethod
-    def start_internal_traffic_generators(emulation_env_config: EmulationEnvConfig) -> None:
+    def start_internal_traffic_generators(emulation_env_config: EmulationEnvConfig, physical_server_ip: str,
+                                          logger: logging.Logger) -> None:
         """
         Utility function for starting internal traffic generators
 
         :param emulation_env_config: the configuration of the emulation env
+        :param physical_server_ip: the ip of the physical server
+        :param logger: the logger to use for logging
         :return: None
         """
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
+            if node_traffic_config.physical_host_ip != physical_server_ip:
+                continue
             container = None
             for c in emulation_env_config.containers_config.containers:
                 if node_traffic_config.ip in c.get_ips():
@@ -410,26 +461,27 @@ class TrafficController:
             else:
                 TrafficController.start_internal_traffic_generator(
                     emulation_env_config=emulation_env_config, node_traffic_config=node_traffic_config,
-                    container=container)
+                    container=container, logger=logger)
 
     @staticmethod
     def start_internal_traffic_generator(
             emulation_env_config: EmulationEnvConfig, node_traffic_config: NodeTrafficConfig,
-            container: NodeContainerConfig) -> None:
+            container: NodeContainerConfig, logger: logging.Logger) -> None:
         """
         Utility function for starting internal traffic generators
 
         :param emulation_env_config: the configuration of the emulation env
         :param node_traffic_config: the node traffic configuration
         :param container: the container
+        :param logger: the logger to use for logging
         :return: None
         """
         if node_traffic_config is None or container is None:
             return
         TrafficController.start_traffic_manager(emulation_env_config=emulation_env_config,
-                                                node_traffic_config=node_traffic_config)
-        Logger.__call__().get_logger().info(f"Starting traffic generator script, "
-                                            f"node ip:{node_traffic_config.ip}")
+                                                node_traffic_config=node_traffic_config, logger=logger)
+        logger.info(f"Starting traffic generator script, "
+                    f"node ip:{node_traffic_config.docker_gw_bridge_ip}")
 
         commands = []
         subnet_masks = []
@@ -454,7 +506,7 @@ class TrafficController:
 
         # Open a gRPC session
         with grpc.insecure_channel(
-                f'{node_traffic_config.ip}:{node_traffic_config.traffic_manager_port}') as channel:
+                f'{node_traffic_config.docker_gw_bridge_ip}:{node_traffic_config.traffic_manager_port}') as channel:
             stub = csle_collector.traffic_manager.traffic_manager_pb2_grpc.TrafficManagerStub(channel)
             csle_collector.traffic_manager.query_traffic_manager.start_traffic(stub, commands=commands,
                                                                                sleep_time=sleep_time)
@@ -467,7 +519,7 @@ class TrafficController:
         :param emulation_env_config: the emulation env config
         :return: the list of IP addresses
         """
-        return [emulation_env_config.traffic_config.client_population_config.ip]
+        return [emulation_env_config.traffic_config.client_population_config.docker_gw_bridge_ip]
 
     @staticmethod
     def get_client_managers_ports(emulation_env_config: EmulationEnvConfig) -> List[int]:
@@ -480,12 +532,14 @@ class TrafficController:
         return [emulation_env_config.traffic_config.client_population_config.client_manager_port]
 
     @staticmethod
-    def get_client_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str]) -> ClientManagersInfo:
+    def get_client_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str],
+                                 logger: logging.Logger) -> ClientManagersInfo:
         """
         Extracts the information of the Client managers for a given emulation
 
         :param emulation_env_config: the configuration of the emulation
         :param active_ips: list of active IPs
+        :param logger: the logger to use for logging
         :return: a DTO with the status of the Client managers
         """
         client_managers_ips = TrafficController.get_client_managers_ips(emulation_env_config=emulation_env_config)
@@ -503,7 +557,7 @@ class TrafficController:
                     port=emulation_env_config.traffic_config.client_population_config.client_manager_port)
                 running = True
             except Exception as e:
-                Logger.__call__().get_logger().debug(
+                logger.debug(
                     f"Could not fetch client manager status on IP:{ip}, error: {str(e)}, {repr(e)}")
             if status is not None:
                 client_managers_statuses.append(status)
@@ -546,7 +600,7 @@ class TrafficController:
         """
         ips = []
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
-            ips.append(node_traffic_config.ip)
+            ips.append(node_traffic_config.docker_gw_bridge_ip)
         return ips
 
     @staticmethod
@@ -563,13 +617,16 @@ class TrafficController:
         return ports
 
     @staticmethod
-    def get_traffic_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str]) \
+    def get_traffic_managers_info(emulation_env_config: EmulationEnvConfig, active_ips: List[str],
+                                  physical_host_ip: str, logger: logging.Logger) \
             -> TrafficManagersInfo:
         """
         Extracts the information of the traffic managers for a given emulation
 
         :param emulation_env_config: the configuration of the emulation
         :param active_ips: list of active IPs
+        :param physical_host_ip: the ip of the physical host
+        :param logger: the logger to use for logging
         :return: a DTO with the status of the traffic managers
         """
         traffic_managers_ips = TrafficController.get_traffic_managers_ips(emulation_env_config=emulation_env_config)
@@ -577,18 +634,20 @@ class TrafficController:
         traffic_managers_statuses = []
         traffic_managers_running = []
         for node_traffic_config in emulation_env_config.traffic_config.node_traffic_configs:
-            if node_traffic_config.ip not in active_ips:
+            if node_traffic_config.docker_gw_bridge_ip not in active_ips or not EmulationUtil.physical_ip_match(
+                    emulation_env_config=emulation_env_config, ip=node_traffic_config.docker_gw_bridge_ip,
+                    physical_host_ip=physical_host_ip):
                 continue
             running = False
             status = None
-            if node_traffic_config.ip in traffic_managers_ips:
+            if node_traffic_config.docker_gw_bridge_ip in traffic_managers_ips:
                 try:
                     status = TrafficController.get_traffic_manager_status_by_port_and_ip(
-                        port=node_traffic_config.traffic_manager_port, ip=node_traffic_config.ip)
+                        port=node_traffic_config.traffic_manager_port, ip=node_traffic_config.docker_gw_bridge_ip)
                     running = True
                 except Exception as e:
-                    Logger.__call__().get_logger().debug(f"Could not fetch traffic manager status on IP"
-                                                         f":{node_traffic_config}, error: {str(e)}, {repr(e)}")
+                    logger.debug(f"Could not fetch traffic manager status on IP"
+                                 f":{node_traffic_config}, error: {str(e)}, {repr(e)}")
                 if status is not None:
                     traffic_managers_statuses.append(status)
                 else:
