@@ -1,9 +1,22 @@
+import socket
+
 
 class GeneralUtil:
     """
     Class with general utility functions
     """
 
+    @staticmethod
+    def get_host_ip() -> str:
+        """
+        Utility method for getting the ip of the host
+
+        :return: the ip of the host
+        """
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(("8.8.8.8", 80))
+        return s.getsockname()[0]
+
     @staticmethod
     def replace_first_octet_of_ip(ip: str, ip_first_octet: int) -> str:
         """
