@@ -1,3 +1,4 @@
+import logging
 from typing import List
 import time
 import datetime
@@ -18,13 +19,12 @@ from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvCo
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action import EmulationAttackerAction
 from csle_common.dao.emulation_action.defender.emulation_defender_action import EmulationDefenderAction
 from csle_common.dao.emulation_config.emulation_metrics_time_series import EmulationMetricsTimeSeries
-from csle_common.logging.log import Logger
 
 
 class ReadEmulationStatisticsUtil:
 
     @staticmethod
-    def read_all(emulation_env_config: EmulationEnvConfig, time_window_minutes: int = 100) \
+    def read_all(emulation_env_config: EmulationEnvConfig, logger: logging.Logger, time_window_minutes: int = 100) \
             -> EmulationMetricsTimeSeries:
         """
         Reads all time series data from the kafka log
@@ -89,13 +89,13 @@ class ReadEmulationStatisticsUtil:
                        collector_constants.KAFKA_CONFIG.AVERAGE_OPENFLOW_PORT_STATS_PER_SWITCH_TOPIC_NAME,
                        collector_constants.KAFKA_CONFIG.OPENFLOW_AGG_FLOW_STATS_TOPIC_NAME
                        ]
-
+        logger.info(f"Reading time-series data for the last {time_window_minutes} from topics: {topic_names}")
         start_consume_ts = time.time()
         kafka_conf = {
             collector_constants.KAFKA.BOOTSTRAP_SERVERS_PROPERTY:
-                f"{emulation_env_config.kafka_config.container.get_ips()[0]}:"
-                f"{emulation_env_config.kafka_config.kafka_port}",
-            collector_constants.KAFKA.GROUP_ID_PROPERTY: f"attacker_actions_consumer_thread_{start_consume_ts}",
+                f"{emulation_env_config.kafka_config.container.docker_gw_bridge_ip}:"
+                f"{emulation_env_config.kafka_config.kafka_port_external}",
+            collector_constants.KAFKA.GROUP_ID_PROPERTY: f"emulation_data_consumer_thread_{start_consume_ts}",
             collector_constants.KAFKA.AUTO_OFFSET_RESET_PROPERTY: collector_constants.KAFKA.EARLIEST_OFFSET}
         consumer = Consumer(**kafka_conf)
         start_consume_ts = int(datetime.datetime.timestamp(datetime.datetime.now()
@@ -122,8 +122,7 @@ class ReadEmulationStatisticsUtil:
                 num_msg += 1
                 if msg.error():
                     if msg.error().code() == KafkaError._PARTITION_EOF:
-                        Logger.__call__().get_logger.warning(
-                            f"reached end of partition: {msg.topic(), msg.partition(), msg.offset()}")
+                        logger.warning(f"reached end of partition: {msg.topic(), msg.partition(), msg.offset()}")
                     elif msg.error():
                         raise KafkaException(msg.error())
                 else:
